Contributors
============

* Florent Michon <flohcim@gmail.com> [flohcim][fmichon]
* Jean-Yves Madier de Champvermeil <> [jymadier]
* Jérémy Cérini <> [cerini_j][jcerini]
* Kevin Burles <> [KBurles]
* Matthias Broquet <mbroquet@atreal.fr> [mbroquet][tiazma]
* Nicolas Haye <> [nhaye][NHaye]
* Nicolas Meucci <> [nmeucci][oc1n]
* Sofien Timezouaght <> [softime][stimezouaght]
* Virginie Pihour <> [vpihour]

